@@ -1,9 +1,9 @@
 package ColorTheme::Test::Random;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-13'; # DATE
+our $DATE = '2021-08-01'; # DATE
 our $DIST = 'ColorThemes-Test'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use strict;
 use warnings;
@@ -20,6 +20,10 @@ our %THEME = (
             schema => 'bool*',
             default => 1,
         },
+        num => {
+            schema => 'posint*',
+            default => 5,
+        },
         # TODO: whether to set random foreground color or not (default 1)
         # TODO: whether to set random background color or not (default 0)
     },
@@ -28,7 +32,7 @@ our %THEME = (
 sub list_items {
     my $self = shift;
 
-    my @list = [];
+    my @list = [0 .. ($self->{args}{num}//5)-1];
     wantarray ? @list : \@list;
 }
 
@@ -57,7 +61,7 @@ ColorTheme::Test::Random - A color theme which gives random colors
 
 =head1 VERSION
 
-This document describes version 0.003 of ColorTheme::Test::Random (from Perl distribution ColorThemes-Test), released on 2020-06-13.
+This document describes version 0.004 of ColorTheme::Test::Random (from Perl distribution ColorThemes-Test), released on 2021-08-01.
 
 =head1 HOMEPAGE
 
@@ -81,7 +85,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
